@@ -5,7 +5,7 @@
 
 class QwtPlotCurve;
 
-class CpuPlot : public QwtPlot 
+class CpuPlot : public QwtPlot
 {
     Q_OBJECT
 public:
@@ -19,15 +19,17 @@ public:
         NCpuData
     };
 
-    CpuPlot(QWidget * = 0);
-    const QwtPlotCurve *cpuCurve(int id) const
-        { return data[id].curve; }
+    CpuPlot( QWidget * = 0 );
+    const QwtPlotCurve *cpuCurve( int id ) const
+    {
+        return data[id].curve;
+    }
 
 protected:
-    void timerEvent(QTimerEvent *e);
+    void timerEvent( QTimerEvent *e );
 
 private Q_SLOTS:
-    void showCurve(QwtPlotItem *, bool on);
+    void showCurve( QwtPlotItem *, bool on );
 
 private:
     struct
@@ -35,6 +37,7 @@ private:
         QwtPlotCurve *curve;
         double data[HISTORY];
     } data[NCpuData];
+
     double timeData[HISTORY];
 
     int dataCount;
