@@ -20,8 +20,12 @@
 
 static inline bool qwtIsLogarithmic( const QwtThermo *thermo )
 {
-    const QwtScaleTransformation::Type scaleType =
-        thermo->scaleEngine()->transformation()->type();
+    const QwtScaleTransformation* transform =
+        thermo->scaleEngine()->transformation();
+
+    const QwtScaleTransformation::Type scaleType = transform->type();
+
+    delete transform;
 
     return ( scaleType == QwtScaleTransformation::Log10 );
 }
@@ -61,7 +65,7 @@ QVector<double> qwtTickList( const QwtScaleDiv &scaleDiv, double value )
     {
         const QList<double> ticks = scaleDiv.ticks( tickType );
 
-        for ( int i = 0; i < ( int )ticks.count(); i++ )
+        for ( int i = 0; i < ticks.count(); i++ )
         {
             const double v = ticks[i];
             if ( v > lowerLimit && v < upperLimit )
@@ -449,7 +453,7 @@ QRect QwtThermo::pipeRect() const
         scaleDraw()->getBorderDistHint( font(), d1, d2 );
         mbd = qMax( d1, d2 );
     }
-    int bw = d_data->borderWidth;
+    const int bw = d_data->borderWidth;
 
     QRect tRect;
     if ( d_data->orientation == Qt::Horizontal )
@@ -460,7 +464,7 @@ QRect QwtThermo::pipeRect() const
             {
                 tRect.setRect(
                     cr.x() + mbd + bw,
-                    cr.y() + cr.height() - d_data->pipeWidth - 2 * bw,
+                    cr.y() + cr.height() - d_data->pipeWidth - bw,
                     cr.width() - 2 * ( bw + mbd ),
                     d_data->pipeWidth 
                 );
@@ -473,7 +477,7 @@ QRect QwtThermo::pipeRect() const
             {
                 tRect.setRect(
                     cr.x() + mbd + bw,
-                    cr.y() + d_data->borderWidth,
+                    cr.y() + bw,
                     cr.width() - 2 * ( bw + mbd ),
                     d_data->pipeWidth 
                 );
@@ -500,7 +504,7 @@ QRect QwtThermo::pipeRect() const
             default:   
             {
                 tRect.setRect(
-                    cr.x() + cr.width() - 2 * bw - d_data->pipeWidth,
+                    cr.x() + cr.width() - bw - d_data->pipeWidth,
                     cr.y() + mbd + bw,
                     d_data->pipeWidth,
                     cr.height() - 2 * ( bw + mbd ) );
@@ -1011,8 +1015,7 @@ QSize QwtThermo::minimumSizeHint() const
         const int sdLength = scaleDraw()->minLength( font() );
 
         w = sdLength;
-        h = d_data->pipeWidth + sdExtent +
-            d_data->borderWidth + d_data->spacing;
+        h = d_data->pipeWidth + sdExtent + d_data->spacing;
 
     }
     else // no scale
@@ -1027,6 +1030,7 @@ QSize QwtThermo::minimumSizeHint() const
     w += 2 * d_data->borderWidth;
     h += 2 * d_data->borderWidth;
 
+    // finally add the margins
     int left, right, top, bottom;
     getContentsMargins( &left, &top, &right, &bottom );
     w += left + right;
